@@ -51,6 +51,24 @@ class CBResponse:
             }
         }
 
+    def set_image_build_response(
+        self, message: str, response_code: str, image: str,
+        log_file: str, solver_file: str, binary_packages: List[str],
+        exit_code: int
+    ) -> None:
+        self.response_dict = {
+            **self.response_dict,
+            'message': message,
+            'response_code': response_code,
+            'project': image,
+            'image': {
+                'log_file': log_file,
+                'solver_file': solver_file,
+                'binary_packages': binary_packages,
+                'exit_code': exit_code
+            }
+        }
+
     def set_package_buildroot_response(
         self, message: str, response_code: str, package: str,
         log_file: str, solver_file: str, build_root: str, exit_code: int
@@ -76,6 +94,14 @@ class CBResponse:
             message, response_code, package, arch, dist
         )
 
+    def set_image_update_request_response(
+        self, message: str, response_code: str, image: str, arch: str,
+        selection: str
+    ) -> None:
+        self._set_selection_standard_response(
+            message, response_code, image, arch, selection
+        )
+
     def set_package_build_scheduled_response(
         self, message: str, response_code: str, package: str,
         arch: str, dist: str
@@ -84,6 +110,14 @@ class CBResponse:
             message, response_code, package, arch, dist
         )
 
+    def set_image_build_scheduled_response(
+        self, message: str, response_code: str, image: str, arch: str,
+        selection: str
+    ) -> None:
+        self._set_selection_standard_response(
+            message, response_code, image, arch, selection
+        )
+
     def set_package_jobs_reset_response(
         self, message: str, response_code: str, package: str,
         arch: str, dist: str
@@ -92,6 +126,14 @@ class CBResponse:
             message, response_code, package, arch, dist
         )
 
+    def set_image_jobs_reset_response(
+        self, message: str, response_code: str, image: str,
+        arch: str, selection: str
+    ) -> None:
+        self._set_selection_standard_response(
+            message, response_code, image, arch, selection
+        )
+
     def set_buildhost_arch_incompatible_response(
         self, message: str, response_code: str, package: str
     ) -> None:
@@ -121,24 +163,39 @@ class CBResponse:
         return self.response_dict
 
     def _set_standard_response(
-        self, message: str, response_code: str, package: str
+        self, message: str, response_code: str, project: str
     ) -> None:
         self.response_dict = {
             **self.response_dict,
             'message': message,
             'response_code': response_code,
-            'project': package
+            'project': project
+        }
+
+    def _set_selection_standard_response(
+        self, message: str, response_code: str, project: str, arch: str,
+        selection: str
+    ) -> None:
+        self.response_dict = {
+            **self.response_dict,
+            'message': message,
+            'response_code': response_code,
+            'project': project,
+            'target': {
+                'arch': arch,
+                'selection': selection
+            }
         }
 
     def _set_dist_standard_response(
-        self, message: str, response_code: str, package: str,
+        self, message: str, response_code: str, project: str,
         arch: str, dist: str
     ) -> None:
         self.response_dict = {
             **self.response_dict,
             'message': message,
             'response_code': response_code,
-            'project': package,
+            'project': project,
             'target': {
                 'arch': arch,
                 'dist': dist
